% Function to reproduce Table 1 in "Nonparametric Nearest Neighbor Random
% Process Clustering" by Michael Tschannen and Helmut Boelcskei

% mode: 1: Subject #16, 2: Subject #35

function testMOCAP(mode)
    s = RandStream('mcg16807','Seed',1);
    RandStream.setGlobalStream(s);
    
    % Index of the marker sequence used for clustering
    markeridx = 53;
    
    L = 2;
    q = 6;

    if mode == 2
        infolder = '../MOCAP_S35/';
        N = 33;
        % Maximum observation length
        maxlen = 497;
        % Ground truth
        gt = ones(N,1);
        gt(17:26) = 2;
    else
        infolder = './MOCAP_S16/';
        N = 49;
        maxlen = 580;
        gt = ones(N,1);
        gt([1 26:37 39:48]) = 2;
    end
    
    files = dir(infolder);

    X = zeros(2*maxlen-1,N);

    % Offset file list index to skip '.', '..' and hidden files
    startidx = length(files) - N + 1;

    for i = startidx:length(files)
        data = amc_to_matrix(strcat(infolder, files(i).name));
        len = length(data(:,1));
        % Estimate PSD via Blackman-Tukey PSD estimator
        x = abs(fft([0; gausswin(2*len-1).*xcorr(data(:,markeridx))],2*maxlen-1));
        X(:,i-startidx+1) = x;
    end

    % Shuffle data
    idxperm = randperm(N);
    X = X(:,idxperm);
    gt = gt(idxperm);

    % Normalixe PSD estimates to unit power
    X = X*diag(1./sum(X,1));

    % Compute dissimilarity matrix
    D = zeros(size(X,2));
    for k = 1:size(X,2)
        for l = k:size(X,2)
            D(k,l) = sum(abs(X(:,k)-X(:,l)))/2;
            D(l,k) = D(k,l);
        end
    end

    labelsNNPC = NNPCDist(D,q,L);
    labelsKM = kmfarthest(D,L);
    fprintf('NNPC: CE = %f, S = %f \nKM:   CE = %f, S = %f \n ',...
        computece(labelsNNPC,gt),clusconfent2(labelsNNPC,gt),...
        computece(labelsKM,gt),clusconfent2(labelsKM,gt))
end


